datahike.index.utils


datom-to-vecclj

(datom-to-vec datom index-type start?)

equals-on-indices?clj

(equals-on-indices? k1 k2 indices)

Returns true if 'k1' and 'k2' have the same value at positions indicated by 'indices'

Returns true if 'k1' and 'k2' have the same value at positions indicated by 'indices'
raw docstring

prefix-scanclj

(prefix-scan cmp [e f g h])

cljdoc builds & hosts documentation for Clojure/Script libraries